nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

RTestcode

Struct RTestcode 

#[repr(transparent)]
pub struct RTestcode(pub u32);
BIST Test Code Register

Tuple Fields

0: u32

Implementations

Source

impl RTestcode

pub const fn testcode(&self) -> u8

Used to store test code information before running TMR-RST/TMRSET BIST command

pub const fn set_testcode(&mut self, val: u8)

Used to store test code information before running TMR-RST/TMRSET BIST command